summaryrefslogtreecommitdiffstats
path: root/style/src/text_input.rs
diff options
context:
space:
mode:
Diffstat (limited to 'style/src/text_input.rs')
-rw-r--r--style/src/text_input.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/style/src/text_input.rs b/style/src/text_input.rs
index 5e703e61..73b05852 100644
--- a/style/src/text_input.rs
+++ b/style/src/text_input.rs
@@ -12,8 +12,8 @@ pub struct Appearance {
pub border_width: f32,
/// The border [`Color`] of the text input.
pub border_color: Color,
- /// The handle [`Color`] of the text input.
- pub handle_color: Color,
+ /// The icon [`Color`] of the text input.
+ pub icon_color: Color,
}
/// A set of rules that dictate the style of a text input.